@@ -4,7 +4,7 @@
 modname = 'trackervcs'
 distname = 'cubicweb-trackervcs'
 
-numversion = (1, 0, 4)
+numversion = (1, 1, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -14,11 +14,11 @@ description = 'vcsfile / tracker integration'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 __depends__ = {'cubicweb': '>= 3.15.8',
-               'cubicweb-vcsfile': '>= 1.12.0',
-               'cubicweb-tracker': None,
+               'cubicweb-vcsfile': '>= 1.12.3',
+               'cubicweb-tracker': '>= 1.12.0',
                }
-__recommends__ = {'cubicweb-vcreview': '>= 1.0.0',
-                  'cubicweb-forge': None, # only for force import order
+__recommends__ = {'cubicweb-vcreview': '>= 1.1.0',
+                  'cubicweb-forge': '>=1.9.0', # only for force import order
                   }
 
 
